@@ -21,6 +21,7 @@ use 5.012;
 use strict;
 use warnings;
 use Data::Dumper;
+use Data::Printer;
 use Filter::Simple;
 use Term::ReadLine;
 use Term::ANSIColor qw( colored );
@@ -29,10 +30,10 @@ use Scalar::Util    qw( blessed reftype );
 use Class::Tiny     qw( term attr debug );
 use feature         qw( say state );
 use parent          qw( Exporter );
-use subs            qw( p uniq );
+use subs            qw( d uniq );
 
-our $VERSION = '0.12';
-our @EXPORT  = qw( run p );
+our $VERSION = '0.13';
+our @EXPORT  = qw( run p d );
 our $FILTER  = 1;
 
 =head1 NAME
@@ -297,6 +298,7 @@ sub _init {
 
 sub _step {
     my ( $self ) = @_;
+    my $is_data_dumper_command = qr{ ^ d \b }x;
 
     if ( not $self->{vars_all} ) {
         $self->_setup_vars;
@@ -307,7 +309,7 @@ sub _step {
     say "input_after_readline=[$input]" if $self->debug;
 
     # Change '#1' to '--maxdepth=1'
-    if ( $input =~ / ^ p\b /x ) {
+    if ( $input =~ /$is_data_dumper_command/ ) {
         $input =~ s/
             \s*
             \#(\d)     #2 to --maxdepth=2
@@ -346,7 +348,8 @@ sub _complete {
     # Help or History command - complete the word.
     return $self->_complete_h( @_ ) if $line =~ / ^ \s* h \w* $ /x;
 
-    # Print command - space afterwards.
+    # Dump/Print command - space afterwards.
+    return $self->_complete_d( @_ ) if $line =~ / ^ \s* d $ /x;
     return $self->_complete_p( @_ ) if $line =~ / ^ \s* p $ /x;
 
     # Method call or coderef - append "(".
@@ -393,6 +396,14 @@ sub _complete_h {
     );
 }
 
+sub _complete_d {
+    my $self = shift;
+    my ( $text, $line, $start, $end ) = @_;
+    $self->_dump_args( @_ ) if $self->debug;
+
+    $self->_match( words => ["d"] );
+}
+
 sub _complete_p {
     my $self = shift;
     my ( $text, $line, $start, $end ) = @_;
@@ -565,7 +576,8 @@ sub _define_commands {
     (
         "help",    # Changed in _step to $repl->help().
         "hist",    # Changed in _step to $repl->hist().
-        "p",       # Exporting it.
+        "p",       # From Data::Printer and exporting it.
+        "d",       # Exporting it.
         "q",       # Used in _step to stop the repl.
     );
 }
@@ -758,7 +770,8 @@ sub _define_help {
  <TAB>       - Show options.
  help        - Show this help section.
  hist [N=20] - Show last N commands.
- p DATA [#N] - Prety print data (with optional depth),
+ p VAR       - Data printer.
+ d DATA [#N] - Data dumper (with optional depth).
  q           - Quit debugger.
 HELP
 }
@@ -888,16 +901,16 @@ sub _save_history {
 
 # Print
 
-=head2 p
+=head2 d
 
 Data::Dumper::Dump anything.
 
- p 123
- p [1, 2, 3]
+ d 123
+ d [1, 2, 3]
 
 Can adjust the maxdepth (default is 1) to see with: "#Number".
 
- p { a => [1, 2, 3] } #1
+ d { a => [1, 2, 3] } #1
 
 Output:
 
@@ -909,7 +922,7 @@ Set maxdepth to '0' to show all nested structures.
 
 =cut
 
-sub p {
+sub d {
 
     # Use same function to change maxdepth of whats shown.
     my $maxdepth =
